#
# ESI Management
#

#install.packages(c("feather", "ggplot2", "dplyr", "rworldmap))

library(feather)
library(ggplot2)
library(dplyr)
library(rworldmap)

#
# Q1: What is a distribution of AI companies by countries ? ----
#

df <- read_feather("wp_esi_entity") %>% 
  group_by(country) %>% 
  summarise(sum = n()) %>% 
  arrange(-sum) %>% 
  mutate(country = ifelse(country=="", "NA", country))  

# Countries with more than 100 startups
df %>% 
  filter(sum > 100) %>% 
  ggplot(aes(reorder(country, sum), sum)) +
  ggtitle("Countries with more than 100 startups") +
  ylab("Number of startups") +
  xlab("Countries") +
  geom_bar(stat="identity") +
  theme_bw() +
  coord_flip()

# Countries with 10-100 startups
df %>% 
  filter(sum %in% 10:100) %>% 
  ggplot(aes(reorder(country, sum), sum)) +
  ggtitle("Countries with 10-100 startups") +
  xlab("Countries") +
  ylab("Number of startups") +
  geom_bar(stat="identity") +
  theme_bw() +
  coord_flip() +
  coord_polar()

# Countries with 1-10 startups
df %>% 
  filter(sum %in% 1:10) %>% 
  ggplot(aes(reorder(country, sum), sum)) +
  ggtitle("Countries with 1-10 startups") +
  xlab("Countries") +
  ylab("Number of startups") +  
  geom_bar(stat="identity") +
  theme_bw() +
  coord_flip()

write.csv(df, "q1.csv", row.names = FALSE)

# 2. Statistics on the Map ---------------------------------------------------

# 1. Create a map-shaped window
mapDevice('x11')

# 2. Join to a coarse resolution map
spdf <- joinCountryData2Map(df, joinCode="NAME", nameJoinColumn="country")

# 3. Plot
mapCountryData(spdf, nameColumnToPlot="sum", catMethod="fixedWidth")
